@@ -37,9 +37,9 @@ class init_anim:
 
 
         Arguments:
-        :param t (nd.array): contains the time information that corresponds with the six degrees of freedom data 
-        :param speed_up (float): the "real time speed up" or the ratio of the duration of the data to the duration of the animation 
-        :param scale (float): global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
+            :param t (nd.array): contains the time information that corresponds with the six degrees of freedom data 
+            :param speed_up (float): the "real time speed up" or the ratio of the duration of the data to the duration of the animation 
+            :param scale (float): global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
 
         """
 
@@ -73,9 +73,9 @@ class ref_frame:
 
 
         Arguments:
-        :param name (str): the Blender object name of the reference frame
-        :param parent (bpy.data.object): the Blender object parent of this reference frame 
-        :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
+            :param name (str): the Blender object name of the reference frame
+            :param parent (bpy.data.object): the Blender object parent of this reference frame 
+            :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
 
         """
         self.name = name
@@ -109,10 +109,10 @@ class ref_frame:
 
 
         Arguments:
-        :param quat (nd.array): an numpy array of one quaternion
-        :param x (float): the x position 
-        :param y (float): the y position 
-        :param z (float): the z position 
+            :param quat (nd.array): an numpy array of one quaternion
+            :param x (float): the x position 
+            :param y (float): the y position 
+            :param z (float): the z position 
 
         """
         if not(quat is None):
@@ -134,10 +134,10 @@ class ref_frame:
 
 
         Arguments:
-        :param quat (nd.array): an numpy array of quaternions over time
-        :param x (nd.array): the x position over time
-        :param y (nd.array): the y position over time
-        :param z (nd.array): the z position over time
+            :param quat (nd.array): an numpy array of quaternions over time
+            :param x (nd.array): the x position over time
+            :param y (nd.array): the y position over time
+            :param z (nd.array): the z position over time
 
         """
 
@@ -174,11 +174,11 @@ class dyn_obj:
         The main building block of all dynamic visualizations 
 
         Arguments:
-        :param obj (bpy.data.object): the Blender object that will be animated
-        :param pa (iterable[float]): the offset of the principal axes specified by the :param euler_type:
-        :param euler_type (str): the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
-        :param parent (bpy.data.object): the Blender object parent of this reference frame 
-        :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
+            :param obj (bpy.data.object): the Blender object that will be animated
+            :param pa (iterable[float]): the offset of the principal axes specified by the :param euler_type:
+            :param euler_type (str): the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
+            :param parent (bpy.data.object): the Blender object parent of the original object 
+            :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
 
         """
 
@@ -238,10 +238,10 @@ class dyn_obj:
         Creates a static or dynamic positional streamline for a :class:`~bpsci.core.dyn_obj`
 
         Arguments:
-        :param staticity (str): a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
-        :param int_x (nd.array): a numpy array of the x position over time
-        :param int_y (nd.array): a numpy array of the y position over time
-        :param int_z (nd.array): a numpy array of the z position over time
+            :param staticity (str): a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
+            :param int_x (nd.array): a numpy array of the x position over time
+            :param int_y (nd.array): a numpy array of the y position over time
+            :param int_z (nd.array): a numpy array of the z position over time
         """
 
 
@@ -290,14 +290,15 @@ class dyn_obj:
 class dyn_vec:
     def __init__(self, parent, name, scale_mag, scale_off, offset, anim):
         """
-        Creates a dynamic vector`
+        Initializes a dynamic vector`
 
         Arguments:
-        :param obj (bpy.data.object): the Blender object the vector is associated with
-        :param name (str): the Blender object name of the vector ('_vector' will be appended to this name)
-        :param scale_mag (float): the scaling factor of the vector's magnitude axis (purely aesthetic)
-        :param scale_off (float): the scaling factor of the vector's off-axes (purely aesthetic)
-        :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
+            :param parent (bpy.data.object): the Blender object the vector is associated with
+            :param name (str): the Blender object name of the vector ('_vector' will be appended to this name)
+            :param scale_mag (float): the scaling factor of the vector's magnitude axis (purely aesthetic)
+            :param scale_off (float): the scaling factor of the vector's off-axes (purely aesthetic)
+            :param offset (tuple[float]): offset of vector from the parent object (purely aesthetic)
+            :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
         """
 
 
@@ -305,15 +306,19 @@ class dyn_vec:
         """bpy.data.object: the Blender object parent of this reference frame"""
 
         self.name = name+"_vector"
-         """str: the Blender object name of the vector"""
+        """str: the Blender object name of the vector"""
         
         self.parent_rf = ref_frame(self.name+"_empty", self.parent, anim)
+        """bpy.data.object: holds the vector"""
 
         self.filepath = self.filepath = __file__.replace("__init__.py", "").replace("\\core.py", "")+'\\assets\\objects\\arrow.obj' #"C:/Users/vargh/Documents/GitHub/bpsci/bpsci/assets/objects/arrow.obj" #bpsci.__file__.replace("__init__.py", "")+'\\assets\\objects\\arrow.obj'
+        """str: file path to arrow asset"""
+
 
         vec = bpy.ops.import_scene.obj(filepath=self.filepath)
         vec = bpy.context.selected_objects[0]
         self.vec = vec
+        """bpy.data.object: the actual arrow asset"""
         
         self.parent_rf.ob.location = offset
         vec.parent = self.parent_rf.ob
@@ -322,10 +327,20 @@ class dyn_vec:
         self.scale = scale_mag
         vec.scale = (scale_mag, scale_off, scale_off)
         self.anim = anim
+        """:class:`~bpsci.core.init_anim`: class object that was used to initialize the animation"""
         
         self.frames = anim.frames
         """iterable[float]: the frames that Blender will animate and have corresponding data for"""
     def animate(self, x, y, z):
+        """
+        Animates a dynamic vector
+
+        Arguments:
+        :param x (nd.array): a numpy array of the x component over time
+        :param y (nd.array): a numpy array of the y component over time
+        :param z (nd.array): a numpy array of the z component over time
+        """
+
         frames = self.frames
 
         max_x = 1
@@ -344,6 +359,7 @@ class dyn_vec:
         norm_z = z/max_z *self.scale
         
         self.point_rf = ref_frame(self.name+"_pointing_empty", self.parent, self.anim)
+        """bpy.data.object: an empty that provides calculates the directionality of the vector"""
         
         tracking_constraint = self.parent_rf.ob.constraints.new('DAMPED_TRACK')
         tracking_constraint.target = self.point_rf.ob
@@ -366,6 +382,18 @@ class dyn_vec:
 
 class anim_text:
     def __init__(self, name, parent, anim, data, label, fix_place, if_str):
+        """
+        Creates animated text
+
+        Arguments:
+        :param name (str): the Blender object name of the text ('_text' will be appended to this name)
+        :param parent (bpy.data.object): the Blender object parent of this text 
+        :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
+        :param data (nd.array): the data to be displayed (same length as the number of animated frames)
+        :param label (str): a label to append to the text (if no label is desired, pass '')
+        :param fix_place (int): the number of decimal places to fix the text to
+        :param if_str (bool): whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
+        """
 
         self.anim = anim
 
